@@ -1,7 +1,8 @@
-from ariadne import ObjectType
+from ariadne import ObjectType, InterfaceType
 
 
 field_error = ObjectType("FieldError")
+payload = InterfaceType("Payload")
 
 
 error_detail = ObjectType("ErrorDetail")
